@@ -35,6 +35,11 @@ class BaseSchema(Schema):
 
     @post_load
     def make_object(self, data, **kwargs):
+        """Create a model object from the provided data.
+
+        :param data: A dictionary of data to populate the model object.
+        :returns An instance of the `model_class`.
+        """
         logging.info("data: %s, kwargs: %s", data, kwargs)
         print(data, kwargs)  # TODO: remove
         return self.model_class(**data)
@@ -49,10 +54,17 @@ class BaseSchema(Schema):
 
 
 class BaseEmbeddedSchema(Schema):
+    """
+
+    """
+
     class Meta:
         unknown = EXCLUDE
 
     @post_load
     def make_object(self, data, **kwargs):
+        """
+
+        """
         logging.info("data: %s", data)
         return self.model_class(**data)
